@@ -17,6 +17,7 @@ var (
 	toggleArgs = []string{
 		config.UPGRADENOTICE,
 		config.AUTOUPGRADE,
+		config.RELOAD,
 	}
 	toggleUse  = fmt.Sprintf("%%s [%s]", strings.Join(toggleArgs, "|"))
 	toggleLong = strings.Join(append([]string{toggleHelpText}, toggleArgs...), "\n- ")
@@ -52,7 +53,7 @@ func toggleFeature(cmd *cobra.Command, feature string, enable bool) {
 	env.Init(flags)
 	defer env.Close()
 
-	if len(feature) == 0 {
+	if feature == "" {
 		_ = cmd.Help()
 		return
 	}
