@@ -2,7 +2,6 @@ package cli
 
 import (
 	"fmt"
-	"os"
 
 	"github.com/jandedobbeleer/oh-my-posh/src/config"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
@@ -24,9 +23,7 @@ var noticeCmd = &cobra.Command{
 		env.Init(flags)
 		defer env.Close()
 
-		sh := os.Getenv("POSH_SHELL")
-		cfg, _ := config.Load(configFlag, sh, false)
-		cfg.Upgrade.Cache = env.Cache()
+		cfg, _ := config.Load(configFlag, false)
 
 		if notice, hasNotice := cfg.Upgrade.Notice(); hasNotice {
 			fmt.Println(notice)
