@@ -23,15 +23,10 @@ import (
 type SegmentStyle string
 
 func (s *SegmentStyle) resolve(context any) SegmentStyle {
-	txtTemplate := &template.Text{
-		Context: context,
-	}
-
-	txtTemplate.Template = string(*s)
-	value, err := txtTemplate.Render()
+	value, err := template.Render(string(*s), context)
 
 	// default to Plain
-	if err != nil || len(value) == 0 {
+	if err != nil || value == "" {
 		return Plain
 	}
 
@@ -75,6 +70,7 @@ type Segment struct {
 	InvertPowerline        bool           `json:"invert_powerline,omitempty" toml:"invert_powerline,omitempty" yaml:"invert_powerline,omitempty"`
 	Force                  bool           `json:"force,omitempty" toml:"force,omitempty" yaml:"force,omitempty"`
 	restored               bool           `json:"-" toml:"-" yaml:"-"`
+	Index                  int            `json:"index,omitempty" toml:"index,omitempty" yaml:"index,omitempty"`
 }
 
 func (segment *Segment) Name() string {
@@ -83,7 +79,7 @@ func (segment *Segment) Name() string {
 	}
 
 	name := segment.Alias
-	if len(name) == 0 {
+	if name == "" {
 		name = c.Title(language.English).String(string(segment.Type))
 	}
 
@@ -146,11 +142,15 @@ func (segment *Segment) Execute(env runtime.Environment) {
 	}
 }
 
-func (segment *Segment) Render(index int) bool {
-	if !segment.Enabled {
+func (segment *Segment) Render(index int, force bool) bool {
+	if !segment.Enabled && !force {
 		return false
 	}
 
+	if force {
+		segment.Force = true
+	}
+
 	segment.writer.SetIndex(index)
 
 	text := segment.string()
@@ -216,7 +216,7 @@ func (segment *Segment) HasEmptyDiamondAtEnd() bool {
 		return false
 	}
 
-	return len(segment.TrailingDiamond) == 0
+	return segment.TrailingDiamond == ""
 }
 
 func (segment *Segment) hasCache() bool {
@@ -295,16 +295,12 @@ func (segment *Segment) cacheKey() string {
 }
 
 func (segment *Segment) folderKey() string {
-	ctx, ok := segment.writer.(cache.Context)
+	key, ok := segment.writer.CacheKey()
 	if !ok {
 		return segment.env.Pwd()
 	}
 
-	if key, OK := ctx.CacheKey(); OK {
-		return key
-	}
-
-	return segment.env.Pwd()
+	return key
 }
 
 func (segment *Segment) string() string {
@@ -313,16 +309,11 @@ func (segment *Segment) string() string {
 		return result
 	}
 
-	if len(segment.Template) == 0 {
+	if segment.Template == "" {
 		segment.Template = segment.writer.Template()
 	}
 
-	tmpl := &template.Text{
-		Template: segment.Template,
-		Context:  segment.writer,
-	}
-
-	text, err := tmpl.Render()
+	text, err := template.Render(segment.Template, segment.writer)
 	if err != nil {
 		return err.Error()
 	}
@@ -383,3 +374,11 @@ func (segment *Segment) evaluateNeeds() {
 		segment.Needs = append(segment.Needs, segmentName)
 	}
 }
+
+func (segment *Segment) key() any {
+	if segment.Index > 0 {
+		return segment.Index - 1
+	}
+
+	return segment.Name()
+}
