@@ -84,7 +84,7 @@ func TestPrintPWD(t *testing.T) {
 
 	for _, tc := range cases {
 		env := new(mock.Environment)
-		if len(tc.Pwd) == 0 {
+		if tc.Pwd == "" {
 			tc.Pwd = "pwd"
 		}
 
@@ -96,7 +96,7 @@ func TestPrintPWD(t *testing.T) {
 
 		template.Cache = &cache.Template{
 			Shell:    tc.Shell,
-			Segments: maps.NewConcurrent(),
+			Segments: maps.NewConcurrent[any](),
 		}
 		template.Init(env, nil, nil)
 
@@ -117,13 +117,13 @@ func TestPrintPWD(t *testing.T) {
 }
 
 func BenchmarkEngineRender(b *testing.B) {
-	for i := 0; i < b.N; i++ {
+	for b.Loop() {
 		engineRender()
 	}
 }
 
 func engineRender() {
-	cfg, _ := config.Load("", shell.GENERIC, false)
+	cfg, _ := config.Load("", false)
 
 	env := &runtime.Terminal{}
 	env.Init(nil)
@@ -131,7 +131,7 @@ func engineRender() {
 	defer env.Close()
 
 	template.Cache = &cache.Template{
-		Segments: maps.NewConcurrent(),
+		Segments: maps.NewConcurrent[any](),
 	}
 	template.Init(env, nil, nil)
 
@@ -199,7 +199,7 @@ func TestGetTitle(t *testing.T) {
 			HostName: "MyHost",
 			PWD:      tc.Cwd,
 			Folder:   "vagrant",
-			Segments: maps.NewConcurrent(),
+			Segments: maps.NewConcurrent[any](),
 		}
 		template.Init(env, nil, nil)
 
@@ -261,7 +261,7 @@ func TestGetConsoleTitleIfGethostnameReturnsError(t *testing.T) {
 			UserName: "MyUser",
 			Root:     tc.Root,
 			HostName: "",
-			Segments: maps.NewConcurrent(),
+			Segments: maps.NewConcurrent[any](),
 		}
 		template.Init(env, nil, nil)
 
@@ -373,7 +373,7 @@ func TestShouldFill(t *testing.T) {
 
 		template.Cache = &cache.Template{
 			Shell:    shell.GENERIC,
-			Segments: maps.NewConcurrent(),
+			Segments: maps.NewConcurrent[any](),
 		}
 		template.Init(env, nil, nil)
 
